Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
src/abcd_graph/__init__.py | 3 | 0 | 0 | 100%
src/abcd_graph/callbacks/__init__.py | 4 | 0 | 0 | 100%
src/abcd_graph/callbacks/abstract.py | 19 | 0 | 0 | 100%
src/abcd_graph/callbacks/property_collector.py | 48 | 0 | 0 | 100%
src/abcd_graph/callbacks/stats_collector.py | 35 | 0 | 0 | 100%
src/abcd_graph/callbacks/visualizer.py | 67 | 1 | 0 | 99%
src/abcd_graph/exporter.py | 40 | 0 | 4 | 100%
src/abcd_graph/graph/__init__.py | 2 | 0 | 0 | 100%
src/abcd_graph/graph/community.py | 10 | 0 | 2 | 100%
src/abcd_graph/graph/core/__init__.py | 0 | 0 | 0 | 100%
src/abcd_graph/graph/core/abcd_objects/__init__.py | 4 | 0 | 0 | 100%
src/abcd_graph/graph/core/abcd_objects/abstract.py | 31 | 0 | 0 | 100%
src/abcd_graph/graph/core/abcd_objects/community.py | 64 | 1 | 0 | 98%
src/abcd_graph/graph/core/abcd_objects/edge.py | 22 | 1 | 0 | 95%
src/abcd_graph/graph/core/abcd_objects/graph_impl.py | 205 | 5 | 0 | 98%
src/abcd_graph/graph/core/abcd_objects/utils.py | 27 | 0 | 0 | 100%
src/abcd_graph/graph/core/build.py | 102 | 2 | 0 | 98%
src/abcd_graph/graph/core/constants.py | 2 | 0 | 0 | 100%
src/abcd_graph/graph/core/exceptions.py | 3 | 0 | 0 | 100%
src/abcd_graph/graph/core/utils.py | 20 | 0 | 2 | 100%
src/abcd_graph/graph/graph.py | 93 | 0 | 0 | 100%
src/abcd_graph/logger.py | 37 | 0 | 20 | 100%
src/abcd_graph/models.py | 24 | 0 | 0 | 100%
src/abcd_graph/params.py | 34 | 0 | 0 | 100%
src/abcd_graph/utils.py | 20 | 0 | 0 | 100%
src/abcd_graph/version.py | 3 | 3 | 0 | 0%
Total | 919 | 13 | 28 | 99%

No items found using the specified filter.